{% extends 'bingo/base.html' %}
{% load i18n %}
{% load staticfiles %}
{% block title %}{% trans 'Game #' %}{{ game.game_id }}{% endblock %}
{% block extra_head %}
    {{ block.super }}
    <script src="{% static 'bingo/js/board_list.js' %}"></script>
{% endblock %}
{% block headline %}{% trans 'Game #' %}{{ game.game_id }}{% endblock %}
{% block content %}
{% with game.bingoboard_set.all as boards %}
<div class="cf"></div>
    {% include "bingo/board_list.html" %}
{% endwith %}
{% endblock %}
