<!DOCTYPE HTML>
<html lang="en">
{% load static from staticfiles %}
{% load i18n %}
<head>
	<meta charset="UTF-8">
    <title>{% block full_title %}Bingo - {% block title %}{% endblock %}{% endblock %}</title>
    <script src="{% static 'js/jquery.js' %}"></script>
    <link rel="stylesheet" type="text/css" href="{% static 'bingo/style.css' %}" />
    {% if site_theme %}
        <link rel="stylesheet" type="text/css" href="{{ site_theme }}" />
    {% endif %}
    {% if user_theme %}
        <link rel="stylesheet" type="text/css" href="{{ user_theme }}" />
    {% endif %}
    <style>
{% block extra_style %}
{% endblock %}
    </style>
{% block extra_head %}
{% endblock %}
</head>
<body>
<div id="wrap" style="min-height: 100%">
    {% block header %}
    <div class="header">
        <h1><a href="{% url 'bingo.views.main' %}"{% block sitename %}>Bingo</a>{% endblock %} - {% block headline %}{% endblock %}</h1>
    </div>
    {% endblock %}
    {% if themes %}
        {% include "bingo/theme_chooser.html" %}
    {% endif %}
    <div class="content">
        {% block extra_content_top %}
        {% endblock %}
        {% block content %}
        {% endblock %}
        {% block extra_content_bottom %}
        {% endblock %}
    </div>
</div>
{% block footer %}
<div class="footer">
    <small>{% trans "powered by django-bingo" %}</small>
</div>
{% endblock footer %}
</body>
</html>
