body {
    position: absolute;
    width: 100%;
    height: 100%;
    margin: 0;
    background: url("background.png") fixed;
    color: black;
}
#wrap {
    min-height: 100%;
}
div.footer {
    text-align: right;
    clear: both;
    margin-top: -1.5em;
    height: 1em;
    width: 100%;
}
div.footer small {
    padding: 0 0.5em;
}
a {
    text-decoration: none;
    color: blue;
}
div.header a {
    color: white;
    text-decoration: none;
}
div.content {
    padding: 0.5ex 2ex;
}
.header {
    margin-bottom: 1ex;
    background-color: darkgreen;
    color: white;
    white-space:nowrap;
    overflow:hidden;
}
.header h1 {
    margin: 0;
    padding: 0.5ex;
}
td.bingofield, li.word {
    background-color: white;
    vertical-align: top;
    border: thin solid black;
    text-align: right;
}
li.word.veto, td.bingofield.veto {
    color: red;
}
td.bingofield.middle {
    background-color: #999;
    color: white;
}
td.bingofield div.bingofield {
    padding: 2em;
    text-align: center;
}
.clickable {
    cursor: pointer;
}
.veto {
    color: red;
}
ul.words li.word form.voteform {
    display: inline;
    float: right;
}
ul.words {
    padding: 0;
    list-style: none;
}
li.word{
    float: left;
    width: 24em;
    margin: 1px;
}
li.word div.word {
    float: left;
    padding: 1ex;
}
li.word form.voteform input {
    background-color: inherit;
    border: thin solid grey;
    width: 2em;
}
.gamelist_header {
    font-weight: bold;
    margin: 0;
}
span.form_header {
    font-weight: bold;
}
fieldset.reclaim_form, fieldset.create_form {
    border: 2px solid darkgreen;
    display: table;
    padding: 1ex;
}
div.reclaim_form, div.create_form {
    float: left;
}
div.reclaim_form {
    margin-left: 1ex;
}
form.reclaim_form p, form.create_form p {
    margin: 0;
}
table.create_form {
    text-align: right;
}
ul.errorlist {
    list-style: none;
    margin: 0;
    padding: 0.5ex 1ex;
    background-color: red;
    color: white;
}
#num_users_table {
    float: right;
}
#num_users_table th {
    text-align: right;
}
#num_users_table td {
    text-align: left;
}

table.current_game th {
    text-align: right;
}
ul.board_list, ul.game_list {
    list-style: none;
    padding: 0;
    margin-top: 0.5ex;
}
ul.board_list {
    margin-bottom: 1.5ex;
}
ul.board_list li.thumbnail {
    float: left;
}
div.board_thumbnail_box {
    display: inline-block;
    margin-right: 0.6ex;
    margin-bottom: 0.6ex;
    padding: 0.5ex;
    border-width: 0.3ex;
    border-style: solid;
    min-width: 200px;
}
input {
    background-color: lightgrey;
    color: black;
    border: thin solid grey;
}
input[type=submit] {
    margin: 5px 0px;
}
input.vote_button {
    background-color: lightgrey;
    color: black;
    border: thin solid darkgrey;
    margin: 1px;
}

ul.pagination {
    padding: 0;
    list-style: none;
}
ul.pagination li {
    margin: 0.5ex;
    border: thin solid darkgrey;
    background-color: lightgrey;
    padding: 0.5ex 1ex;
    float: left;
}
ul.pagination li.inactive {
    color: #808080;
}

#theme_chooser {
    float: right;
}

.cf:before, .cf:after {
    content: " ";
    display: table;
}
.cf:after {
    clear: both;
}
.cf {
    *zoom: 1;
}
table.game_list td {
    padding: 0 0.5ex;
    text-align: right;
}
table.game_list th {
    padding: 0 0.5ex;
    text-align: left;
}
