{% extends 'bingo/base.html' %}
{% load i18n %}
{% block title %}{% trans 'Reclaim your board' %}{% endblock %}
{% block headline %}{% trans 'Reclaim your board' %}{% endblock %}

{% block content %}
{% include "bingo/forms.html" %}
{% endblock %}
