{% if my_board == board %}
<form action="{% url 'bingo.views.vote' ajax=False %}" method="post" class="voteform">
    {% spaceless %}
    {% csrf_token %}
    <input type="hidden" name="field_id" value="{{ field.id }}" />
    <input type="submit" name="vote" value="-" class="vote_button" />
    <input type="submit" name="vote" value="0" class="vote_button" />
    <input type="submit" name="vote" value="+" class="vote_button" />
    {% endspaceless %}
</form>
{% endif %}
