{% extends 'bingo/base.html' %}
{% load i18n %}
{% load staticfiles %}
{% block title %}{% trans 'logged out' %}{% endblock %}
{% block headline %}{% trans 'logged out' %}{% endblock %}
{% block content %}
{% trans "You are now logged out." %}
{% endblock %}
