{% extends 'bingo/base.html' %}
{% load i18n %}
{% load staticfiles %}
{% block title %}{% trans 'Login' %}{% endblock %}
{% block headline %}{% trans 'Login' %}{% endblock %}
{% block content %}
<form action="{% url "auth_login" %}?next={% url "bingo.views.main" %}" method="post">
    {% csrf_token %}
    <table>
    {{ form.as_table }}
    <tr>
        <td colspan="2">
            <input type="submit" value="{% trans "login" %}" />
        </td>
    </tr>
    </table>
</form>
{% endblock %}
